@@ -1,18 +1,11 @@
+from __future__ import annotations
+
 import ast
+import os
 import pkgutil
+import re
 from collections import defaultdict
-from typing import (
-    TYPE_CHECKING,
-    Any,
-    Callable,
-    Dict,
-    Iterable,
-    List,
-    Set,
-    Tuple,
-    Type,
-    TypeVar,
-)
+from typing import TYPE_CHECKING, Any, Callable, Iterable, List, Tuple, TypeVar
 
 from tokenize_rt import Offset, Token
 
@@ -20,21 +13,35 @@ from django_upgrade import fixers
 
 
 class Settings:
-    def __init__(self, target_version: Tuple[int, int]) -> None:
+    def __init__(self, target_version: tuple[int, int]) -> None:
         self.target_version = target_version
 
 
+settings_re = re.compile(r"\bsettings\b")
+
+test_re = re.compile(r"(\b|_)tests?(\b|_)")
+
+
 class State:
     def __init__(
         self,
         settings: Settings,
         filename: str,
-        from_imports: Dict[str, Set[str]],
+        from_imports: dict[str, set[str]],
     ) -> None:
         self.settings = settings
         self.filename = filename
         self.from_imports = from_imports
 
+    def looks_like_migrations_file(self) -> bool:
+        return "migrations" in self.filename.split(os.path.sep)
+
+    def looks_like_settings_file(self) -> bool:
+        return settings_re.search(self.filename) is not None
+
+    def looks_like_test_file(self) -> bool:
+        return test_re.search(self.filename) is not None
+
 
 AST_T = TypeVar("AST_T", bound=ast.AST)
 TokenFunc = Callable[[int, List[Token]], None]
@@ -47,10 +54,10 @@ else:
 
 
 class ASTCallbackMapping(Protocol):
-    def __getitem__(self, tp: Type[AST_T]) -> List[ASTFunc[AST_T]]:  # pragma: no cover
+    def __getitem__(self, tp: type[AST_T]) -> list[ASTFunc[AST_T]]:  # pragma: no cover
         ...
 
-    def items(self) -> Iterable[Tuple[Any, Any]]:  # pragma: no cover
+    def items(self) -> Iterable[tuple[Any, Any]]:  # pragma: no cover
         ...
 
 
@@ -58,7 +65,7 @@ def visit(
     tree: ast.Module,
     settings: Settings,
     filename: str,
-) -> Dict[Offset, List[TokenFunc]]:
+) -> dict[Offset, list[TokenFunc]]:
     ast_funcs = get_ast_funcs(settings.target_version)
     initial_state = State(
         settings=settings,
@@ -66,7 +73,7 @@ def visit(
         from_imports=defaultdict(set),
     )
 
-    nodes: List[Tuple[State, ast.AST, ast.AST]] = [(initial_state, tree, tree)]
+    nodes: list[tuple[State, ast.AST, ast.AST]] = [(initial_state, tree, tree)]
     ret = defaultdict(list)
     while nodes:
         state, node, parent = nodes.pop()
@@ -96,14 +103,14 @@ def visit(
             if isinstance(value, ast.AST):
                 nodes.append((next_state, value, node))
             elif isinstance(value, list):
-                for value in reversed(value):
-                    if isinstance(value, ast.AST):
-                        nodes.append((next_state, value, node))
+                for subvalue in reversed(value):
+                    if isinstance(subvalue, ast.AST):
+                        nodes.append((next_state, subvalue, node))
     return ret
 
 
 class Fixer:
-    def __init__(self, name: str, min_version: Tuple[int, int]) -> None:
+    def __init__(self, name: str, min_version: tuple[int, int]) -> None:
         self.name = name
         self.min_version = min_version
         self.ast_funcs: ASTCallbackMapping = defaultdict(list)
@@ -111,7 +118,7 @@ class Fixer:
         FIXERS.append(self)
 
     def register(
-        self, type_: Type[AST_T]
+        self, type_: type[AST_T]
     ) -> Callable[[ASTFunc[AST_T]], ASTFunc[AST_T]]:
         def decorator(func: ASTFunc[AST_T]) -> ASTFunc[AST_T]:
             self.ast_funcs[type_].append(func)
@@ -120,7 +127,7 @@ class Fixer:
         return decorator
 
 
-FIXERS: List[Fixer] = []
+FIXERS: list[Fixer] = []
 
 
 def _import_fixers() -> None:
@@ -134,7 +141,7 @@ def _import_fixers() -> None:
 _import_fixers()
 
 
-def get_ast_funcs(target_version: Tuple[int, int]) -> ASTCallbackMapping:
+def get_ast_funcs(target_version: tuple[int, int]) -> ASTCallbackMapping:
     ast_funcs: ASTCallbackMapping = defaultdict(list)
     for fixer in FIXERS:
         if target_version >= fixer.min_version:
