@@ -2,9 +2,11 @@
 Rewrite django.db.models.NullBooleanField to BooleanField:
 https://docs.djangoproject.com/en/3.1/releases/3.1/#features-deprecated-in-3-1
 """
+from __future__ import annotations
+
 import ast
 from functools import partial
-from typing import Iterable, List, Tuple
+from typing import Iterable
 
 from tokenize_rt import Offset, Token
 
@@ -30,8 +32,12 @@ def visit_ImportFrom(
     state: State,
     node: ast.ImportFrom,
     parent: ast.AST,
-) -> Iterable[Tuple[Offset, TokenFunc]]:
-    if is_rewritable_import_from(node) and node.module == "django.db.models":
+) -> Iterable[tuple[Offset, TokenFunc]]:
+    if (
+        is_rewritable_import_from(node)
+        and node.module == "django.db.models"
+        and not state.looks_like_migrations_file()
+    ):
         yield ast_start_offset(node), partial(
             update_import_names,
             node=node,
@@ -44,22 +50,25 @@ def visit_Call(
     state: State,
     node: ast.Call,
     parent: ast.AST,
-) -> Iterable[Tuple[Offset, TokenFunc]]:
+) -> Iterable[tuple[Offset, TokenFunc]]:
     if (
-        isinstance(node.func, ast.Name)
-        and "NullBooleanField" in state.from_imports["django.db.models"]
-        and node.func.id == "NullBooleanField"
-    ) or (
-        isinstance(node.func, ast.Attribute)
-        and node.func.attr == "NullBooleanField"
-        and "models" in state.from_imports["django.db"]
-        and isinstance(node.func.value, ast.Name)
-        and node.func.value.id == "models"
-    ):
+        (
+            isinstance(node.func, ast.Name)
+            and "NullBooleanField" in state.from_imports["django.db.models"]
+            and node.func.id == "NullBooleanField"
+        )
+        or (
+            isinstance(node.func, ast.Attribute)
+            and node.func.attr == "NullBooleanField"
+            and "models" in state.from_imports["django.db"]
+            and isinstance(node.func.value, ast.Name)
+            and node.func.value.id == "models"
+        )
+    ) and not state.looks_like_migrations_file():
         yield ast_start_offset(node), partial(fix_null_boolean_field, node=node)
 
 
-def fix_null_boolean_field(tokens: List[Token], i: int, *, node: ast.Call) -> None:
+def fix_null_boolean_field(tokens: list[Token], i: int, *, node: ast.Call) -> None:
     j = find(tokens, i, name=OP, src="(")
     func_args, j = parse_call_args(tokens, j)
 
